@@ -55,6 +55,15 @@ class Invoices(ListoAPI):
         """
         return self.make_request(method="POST", path="/invoices/mark_as_unpaid/%s" % invoice_id).json()
 
+    def delete_payment_with_id(self, invoice_id, payment_id):
+        """Delete specific payment from an invoice
+
+        Args:
+            - invoice_id (str|int): id of the invoice
+            - payment_id (str|int): id of the payment
+        """
+        return self.make_request(method="DELETE", path=f"/invoices/{invoice_id}/payments/{payment_id}/")
+
     def set_dimension(self, invoice_id, dimension_name, dimension_value):
         """Set a dimension value
 
