@@ -6,14 +6,14 @@ class Suppliers(ListoAPI):
     def __init__(self, token, base_url):
         super(Suppliers, self).__init__(token, base_url)
 
-    def supplier_list(self, rfc_id, **kwargs):
+    def supplier_list(self, **kwargs):
         """Get all suppliers"""
         # Change param name for endpoint
         if kwargs.get("rfc"):
             kwargs["q"] = kwargs.pop("rfc")
 
         for s in self.make_request(
-                method="GET", path="/counterparties/suppliers/%s" % rfc_id,
+                method="GET", path="/counterparties/suppliers/",
                 params=kwargs).json()["hits"]:
             yield s
 
